Current Grid Conditions - Southwest Power Pool

- Create Account
- Login

- Create Account
- Login

# Current Grid Conditions

SPP is in normal operations as of Dec. 26, 2022 at 10:00 a.m. CT.

Note: SPP previously issued a Weather Advisory for the SPP Reliability Coordination (RC) footprint in the Eastern Interconnection effective from 8:00 p.m. on Wednesday, Dec. 21 through 10:00 a.m. on Monday, Dec. 26. A Conservative Operations Advisory was in effect until 12:00 a.m., Sunday, Dec. 25. SPP declared two EEA1 alerts on Friday, Dec. 23: the first lasting from 8:27 a.m. CT to 10:00 a.m., and the second lasting from 5:20 p.m. to 8:20 p.m.

To subscribe to receive these updates:

- Once logged into SPP.org, click the “Hi, [your name]” button in the top right of the screen to update your account preferences. (You may have to create an account if you don’t already have one.)
- In the list of available exploders, check the box next to the one named “Grid Notice.”
- Click “Submit” at the bottom of the form to save your changes.
  You can unsubscribe from this and other exploders at any time on the same account management page.

## Descriptions of common reliability events are provided below in increasing order of severity:

Advisories raise awareness and do not require general audiences to take action. SPP member utilities should follow applicable procedures. Energy Emergency Alerts indicate all available generation has been committed to meet region-wide demand. As conditions worsen, voluntary conservation or service interruptions may be necessary to prevent uncontrolled outages.

Normal Operations: SPP has enough generation to meet demand and available reserves, and it foresees no extreme or abnormal threats to reliability.

Weather Advisory: Declared when extreme weather is expected in SPP’s reliability coordination service territory.

Resource Advisory: Declared when severe weather conditions, significant outages, wind-forecast uncertainty and/or load-forecast uncertainty are expected in SPP’s balancing authority area.

Conservative Operations Advisory: Declared when SPP determines there is a need to operate its system conservatively based on weather, environmental, operational, terrorist, cyber or other events.

Energy Emergency Alert Level 1: Declared when all available resources have been committed to meet obligations, and SPP is at risk of not meeting required operating reserves.

Energy Emergency Alert Level 2: Declared when SPP can no longer provide expected energy requirements, or when SPP foresees or has implemented procedures up to, but excluding, service interruptions to maintain regional reliability.

Energy Emergency Alert Level 3: At this level, SPP is utilizing operating reserves such that it is carrying reserves below the required minimum and has initiated assistance through its Reserve Sharing Group. SPP foresees or has implemented firm load obligation interruption. Before requesting an EEA 3, SPP will have already provided the appropriate internal notifications to its Market Participants.

Restoration Event: Defined as a major or catastrophic grid outage which could be a total or partial regional blackout, island situation or system separation.